Page 48 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 48

Home

    One of the lying rumors used to stir the people of
    Paris into insurrection was that 15,000 aristocrats were
    ready to massacre all the patriots. The people were then
    told that, to prevent this planned massacre, the King's
    residence must be invaded and the Monarchy

    mo . °

    and

    overthrown. This was the opposite of what was about to
    happen. It was not the aristocrats who were planning a
    massacre, it was the revolutionaries. As had happened at
    Versailles, when the mob invaded the King's residence,
    he instructed his guards not to fire on the crowd to

    Upon the fall of the Tuileries, the mob went mad in a
    rage of destruction. Everything in their path was an
    object of spoliation. Furniture, mirrors, paintings, art
    work, jewels, all were pillaged or destroyed. Thousands
    of bottles of wine were taken from the wine cellars and

    The Swiss guards who had remained at their posts
    were barbarously butchered, including the wounded that
    lay helpless on the floor. The savage horde tracked down
    their victims from the deepest cellars to the highest
    attics. All were put to death.

    People danced amid torrents of blood and wine. One
    man played the violin beside the corpses as the dead
    bodies were mutilated. Fires were kindled in the

    apartments and "cutlets of Swiss" were grilled and eaten
    in cannibal orgies. One man caught up in a fit of
    revolutionary frenzy, drank a glass of blood.

    43

    The French Revolution

    protect him.

    a drunken orgy followed.